Learn R Programming

devoid (version 0.1.0)

devoid-package: devoid: A Graphic Device That Does Nothing

Description

In order to properly benchmark graphic drawing code it is necessary to factor out the device implemenation itself so that results are not related to the specifc graphics device used during benchmarking. The 'devoid' package implements a graphic device that accepts all the required calls from R's graphic engine but performs no action. Apart from benchmarking it is unlikely that this device has any practical use.

Arguments

See Also

Useful links: